Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Reader ¶
type Reader struct {
Delimiter rune
QuoteChar rune
EscapeChar rune
DoubleQuoteStr string
Encoding string
DoubleQuote bool
NewlinesInValue bool
// contains filtered or unexported fields
}
type Splitter ¶
type Splitter struct {
// contains filtered or unexported fields
}
Splitter splits CSV formatted data into separate entries, taking into account line breaks, quoting and escaping, and writes those entries into the given writer.
func (*Splitter) ConsumeRow ¶
ConsumeRow reads one CSV entry from the input and writes it into the writer.
Click to show internal directories.
Click to hide internal directories.